{ config, lib, pkgs, ... }:

{
  services.emacs.defaultEditor = true;

  users.users.joe = {
    isNormalUser = true;
    description = "Joe bellus";
    extraGroups = [ "networkmanager" "wheel" "audio" "docker" "libvirtd" ];
    packages = with pkgs; [
      alacritty
      firefox
      firefox-devedition-bin
      (builtins.getFlake
        "github:5Sigma/codex?rev=fe20caf8816f8f29aa49e273ba4905496f31c2b1").packages.x86_64-linux.default
      (builtins.getFlake
        "git+https://git.5sigma.io/joe/mbdirnotify.git?rev=dc95988ad4dd6cd019e016be17c1aefbbba96674").packages.x86_64-linux.default
      telegram-desktop
      freecad
      spotify
      mongodb-compass
      pavucontrol
      tectonic
      pandoc
      teams-for-linux
      fuzzel
      protonmail-bridge
      grim
      gnucash
      slurp
      eww-wayland
      mpv
      playerctl
      nil
      stc-cli
      jq
      ledger
      font-awesome
      (import ./scripts/agenda-json.nix { inherit pkgs; })
      (import ./scripts/mail-count.nix { inherit pkgs; })
    ];
  };

  programs.fish.shellAliases = {
    ls = "eza";
    cat = "bat --theme ansi";
  };

  programs.starship.enable = true;

  programs.bash = {
    interactiveShellInit = ''
      if [[ $(${pkgs.procps}/bin/ps --no-header --pid=$PPID --format=comm) != "fish" && -z ''${BASH_EXECUTION_STRING} ]]
      then
        shopt -q login_shell && LOGIN_OPTION='--login' || LOGIN_OPTION=""
        exec ${pkgs.fish}/bin/fish $LOGIN_OPTION
      fi
    '';
  };

}
